@@ -256,7 +256,10 @@ class Blob(_PropertyMixin):
 
     @property
     def public_url(self):
-        """The public URL for this blob's object.
+        """The public URL for this blob.
+
+        Use :meth:`make_public` to enable anonymous access via the returned
+        URL.
 
         :rtype: `string`
         :returns: The public URL for this blob.
@@ -335,7 +338,7 @@ class Blob(_PropertyMixin):
         """
         resource = '/{bucket_name}/{quoted_name}'.format(
             bucket_name=self.bucket.name,
-            quoted_name=quote(self.name))
+            quoted_name=quote(self.name.encode('utf-8')))
 
         if credentials is None:
             client = self._require_client(client)
@@ -1336,7 +1339,7 @@ class Blob(_PropertyMixin):
         return resp.get('permissions', [])
 
     def make_public(self, client=None):
-        """Make this blob public giving all users read access.
+        """Update blob's ACL, granting read access to anonymous users.
 
         :type client: :class:`~google.cloud.storage.client.Client` or
                       ``NoneType``
@@ -1347,8 +1350,7 @@ class Blob(_PropertyMixin):
         self.acl.save(client=client)
 
     def make_private(self, client=None):
-        """Make this blob private by removing `allusers` read access.
-        Does not revoke access for anything other than the `allusers` group.
+        """Update blob's ACL, revoking read access for anonymous users.
 
         :type client: :class:`~google.cloud.storage.client.Client` or
                       ``NoneType``
@@ -1501,8 +1503,6 @@ class Blob(_PropertyMixin):
 
     See `RFC 7234`_ and `API reference docs`_.
 
-    If the property is not set locally, returns :data:`None`.
-
     :rtype: str or ``NoneType``
 
     .. _RFC 7234: https://tools.ietf.org/html/rfc7234#section-5.2
@@ -1513,8 +1513,6 @@ class Blob(_PropertyMixin):
 
     See `RFC 6266`_ and `API reference docs`_.
 
-    If the property is not set locally, returns :data:`None`.
-
     :rtype: str or ``NoneType``
 
     .. _RFC 6266: https://tools.ietf.org/html/rfc7234#section-5.2
@@ -1525,8 +1523,6 @@ class Blob(_PropertyMixin):
 
     See `RFC 7231`_ and `API reference docs`_.
 
-    If the property is not set locally, returns ``None``.
-
     :rtype: str or ``NoneType``
 
     .. _RFC 7231: https://tools.ietf.org/html/rfc7231#section-3.1.2.2
@@ -1537,8 +1533,6 @@ class Blob(_PropertyMixin):
 
     See `BCP47`_ and `API reference docs`_.
 
-    If the property is not set locally, returns :data:`None`.
-
     :rtype: str or ``NoneType``
 
     .. _BCP47: https://tools.ietf.org/html/bcp47
@@ -1549,8 +1543,6 @@ class Blob(_PropertyMixin):
 
     See `RFC 2616`_ and `API reference docs`_.
 
-    If the property is not set locally, returns :data:`None`.
-
     :rtype: str or ``NoneType``
 
     .. _RFC 2616: https://tools.ietf.org/html/rfc2616#section-14.17
@@ -1561,7 +1553,7 @@ class Blob(_PropertyMixin):
 
     See `RFC 4960`_ and `API reference docs`_.
 
-    If the property is not set locally, returns :data:`None`.
+    If not set before upload, the server will compute the hash.
 
     :rtype: str or ``NoneType``
 
@@ -1576,8 +1568,9 @@ class Blob(_PropertyMixin):
 
         :rtype: int or ``NoneType``
         :returns: The component count (in case of a composed object) or
-                  ``None`` if the property is not set locally. This property
-                  will not be set on objects not created via ``compose``.
+                  ``None`` if the blob's resource has not been loaded from
+                  the server.  This property will not be set on objects
+                  not created via ``compose``.
         """
         component_count = self._properties.get('componentCount')
         if component_count is not None:
@@ -1590,7 +1583,8 @@ class Blob(_PropertyMixin):
         See `RFC 2616 (etags)`_ and `API reference docs`_.
 
         :rtype: str or ``NoneType``
-        :returns: The blob etag or ``None`` if the property is not set locally.
+        :returns: The blob etag or ``None`` if the blob's resource has not
+                  been loaded from the server.
 
         .. _RFC 2616 (etags): https://tools.ietf.org/html/rfc2616#section-3.11
         """
@@ -1603,8 +1597,8 @@ class Blob(_PropertyMixin):
         See https://cloud.google.com/storage/docs/json_api/v1/objects
 
         :rtype: int or ``NoneType``
-        :returns: The generation of the blob or ``None`` if the property
-                  is not set locally.
+        :returns: The generation of the blob or ``None`` if the blob's
+                  resource has not been loaded from the server.
         """
         generation = self._properties.get('generation')
         if generation is not None:
@@ -1616,9 +1610,11 @@ class Blob(_PropertyMixin):
 
         See https://cloud.google.com/storage/docs/json_api/v1/objects
 
+        The ID consists of the bucket name, object name, and generation number.
+
         :rtype: str or ``NoneType``
-        :returns: The ID of the blob or ``None`` if the property is not
-                  set locally.
+        :returns: The ID of the blob or ``None`` if the blob's
+                  resource has not been loaded from the server.
         """
         return self._properties.get('id')
 
@@ -1627,7 +1623,7 @@ class Blob(_PropertyMixin):
 
     See `RFC 1321`_ and `API reference docs`_.
 
-    If the property is not set locally, returns ``None``.
+    If not set before upload, the server will compute the hash.
 
     :rtype: str or ``NoneType``
 
@@ -1641,8 +1637,8 @@ class Blob(_PropertyMixin):
         See https://cloud.google.com/storage/docs/json_api/v1/objects
 
         :rtype: str or ``NoneType``
-        :returns: The media link for the blob or ``None`` if the property is
-                  not set locally.
+        :returns: The media link for the blob or ``None`` if the blob's
+                  resource has not been loaded from the server.
         """
         return self._properties.get('mediaLink')
 
@@ -1659,7 +1655,7 @@ class Blob(_PropertyMixin):
 
         :rtype: dict or ``NoneType``
         :returns: The metadata associated with the blob or ``None`` if the
-                  property is not set locally.
+                  property is not set.
         """
         return copy.deepcopy(self._properties.get('metadata'))
 
@@ -1681,8 +1677,8 @@ class Blob(_PropertyMixin):
         See https://cloud.google.com/storage/docs/json_api/v1/objects
 
         :rtype: int or ``NoneType``
-        :returns: The metageneration of the blob or ``None`` if the property
-                  is not set locally.
+        :returns: The metageneration of the blob or ``None`` if the blob's
+                  resource has not been loaded from the server.
         """
         metageneration = self._properties.get('metageneration')
         if metageneration is not None:
@@ -1695,8 +1691,8 @@ class Blob(_PropertyMixin):
         See https://cloud.google.com/storage/docs/json_api/v1/objects
 
         :rtype: dict or ``NoneType``
-        :returns: Mapping of owner's role/ID. If the property is not set
-                  locally, returns ``None``.
+        :returns: Mapping of owner's role/ID, or ``None`` if the blob's
+                  resource has not been loaded from the server.
         """
         return copy.deepcopy(self._properties.get('owner'))
 
@@ -1707,8 +1703,8 @@ class Blob(_PropertyMixin):
         See https://cloud.google.com/storage/docs/json_api/v1/objects
 
         :rtype: str or ``NoneType``
-        :returns: The self link for the blob or ``None`` if the property is
-                  not set locally.
+        :returns: The self link for the blob or ``None`` if the blob's
+                  resource has not been loaded from the server.
         """
         return self._properties.get('selfLink')
 
@@ -1719,8 +1715,8 @@ class Blob(_PropertyMixin):
         See https://cloud.google.com/storage/docs/json_api/v1/objects
 
         :rtype: int or ``NoneType``
-        :returns: The size of the blob or ``None`` if the property
-                  is not set locally.
+        :returns: The size of the blob or ``None`` if the blob's
+                  resource has not been loaded from the server.
         """
         size = self._properties.get('size')
         if size is not None:
@@ -1732,7 +1728,8 @@ class Blob(_PropertyMixin):
 
         :rtype: str or ``NoneType``
         :returns:
-            The resource name or ``None`` if the property is not set locally.
+            The resource name or ``None`` if no Cloud KMS key was used,
+            or the blob's resource has not been loaded from the server.
         """
         return self._properties.get('kmsKeyName')
 
@@ -1760,7 +1757,8 @@ class Blob(_PropertyMixin):
 
         :rtype: :class:`datetime.datetime` or ``NoneType``
         :returns: Datetime object parsed from RFC3339 valid timestamp, or
-                  ``None`` if the property is not set locally. If the blob has
+                  ``None`` if the blob's resource has not been loaded from
+                  the server (see :meth:`reload`). If the blob has
                   not been deleted, this will never be set.
         """
         value = self._properties.get('timeDeleted')
@@ -1775,7 +1773,8 @@ class Blob(_PropertyMixin):
 
         :rtype: :class:`datetime.datetime` or ``NoneType``
         :returns: Datetime object parsed from RFC3339 valid timestamp, or
-                  ``None`` if the property is not set locally.
+                  ``None`` if the blob's resource has not been loaded from
+                  the server (see :meth:`reload`).
         """
         value = self._properties.get('timeCreated')
         if value is not None:
@@ -1789,7 +1788,8 @@ class Blob(_PropertyMixin):
 
         :rtype: :class:`datetime.datetime` or ``NoneType``
         :returns: Datetime object parsed from RFC3339 valid timestamp, or
-                  ``None`` if the property is not set locally.
+                  ``None`` if the blob's resource has not been loaded from
+                  the server (see :meth:`reload`).
         """
         value = self._properties.get('updated')
         if value is not None:
@@ -1870,7 +1870,16 @@ def _raise_from_invalid_response(error):
     :raises: :class:`~google.cloud.exceptions.GoogleCloudError` corresponding
              to the failed status code
     """
-    raise exceptions.from_http_response(error.response)
+    response = error.response
+    error_message = str(error)
+
+    message = u'{method} {url}: {error}'.format(
+        method=response.request.method,
+        url=response.request.url,
+        error=error_message)
+
+    raise exceptions.from_http_status(
+        response.status_code, message, response=response)
 
 
 def _add_query_parameters(base_url, name_value_pairs):
