@@ -18,6 +18,7 @@ import base64
 import copy
 import datetime
 import json
+import warnings
 
 import six
 
@@ -256,7 +257,7 @@ class Bucket(_PropertyMixin):
         except NotFound:
             return False
 
-    def create(self, client=None, project=None):
+    def create(self, client=None, project=None, location=None):
         """Creates current bucket.
 
         If the bucket already exists, will raise
@@ -268,16 +269,21 @@ class Bucket(_PropertyMixin):
 
         :type client: :class:`~google.cloud.storage.client.Client` or
                       ``NoneType``
-        :param client: Optional. The client to use.  If not passed, falls back
+        :param client: Optional. The client to use. If not passed, falls back
                        to the ``client`` stored on the current bucket.
 
         :type project: str
-        :param project: (Optional) the project under which the  bucket is to
-                        be created.  If not passed, uses the project set on
+        :param project: Optional. The project under which the bucket is to
+                        be created. If not passed, uses the project set on
                         the client.
         :raises ValueError: if :attr:`user_project` is set.
         :raises ValueError: if ``project`` is None and client's
                             :attr:`project` is also None.
+
+        :type location: str
+        :param location: Optional. The location of the bucket. If not passed,
+                         the default location, US, will be used. See
+                         https://cloud.google.com/storage/docs/bucket-locations
         """
         if self.user_project is not None:
             raise ValueError("Cannot create bucket with 'user_project' set.")
@@ -294,6 +300,10 @@ class Bucket(_PropertyMixin):
         query_params = {'project': project}
         properties = {key: self._properties[key] for key in self._changes}
         properties['name'] = self.name
+
+        if location is not None:
+            properties['location'] = location
+
         api_response = client._connection.api_request(
             method='POST', path='/b', query_params=query_params,
             data=properties, _target_object=self)
@@ -876,8 +886,8 @@ class Bucket(_PropertyMixin):
              https://cloud.google.com/storage/docs/json_api/v1/buckets
 
         :rtype: str or ``NoneType``
-        :returns: The bucket etag or ``None`` if the property is not
-                  set locally.
+        :returns: The bucket etag or ``None`` if the bucket's
+                  resource has not been loaded from the server.
         """
         return self._properties.get('etag')
 
@@ -888,8 +898,8 @@ class Bucket(_PropertyMixin):
         See https://cloud.google.com/storage/docs/json_api/v1/buckets
 
         :rtype: str or ``NoneType``
-        :returns: The ID of the bucket or ``None`` if the property is not
-                  set locally.
+        :returns: The ID of the bucket or ``None`` if the bucket's
+                  resource has not been loaded from the server.
         """
         return self._properties.get('id')
 
@@ -935,16 +945,42 @@ class Bucket(_PropertyMixin):
         """
         self._patch_property('lifecycle', {'rule': rules})
 
-    location = _scalar_property('location')
-    """Retrieve location configured for this bucket.
+    _location = _scalar_property('location')
 
-    See https://cloud.google.com/storage/docs/json_api/v1/buckets and
-    https://cloud.google.com/storage/docs/bucket-locations
+    @property
+    def location(self):
+        """Retrieve location configured for this bucket.
 
-    If the property is not set locally, returns ``None``.
+        See https://cloud.google.com/storage/docs/json_api/v1/buckets and
+        https://cloud.google.com/storage/docs/bucket-locations
 
-    :rtype: str or ``NoneType``
-    """
+        Returns ``None`` if the property has not been set before creation,
+        or if the bucket's resource has not been loaded from the server.
+        :rtype: str or ``NoneType``
+        """
+        return self._location
+
+    @location.setter
+    def location(self, value):
+        """(Deprecated) Set `Bucket.location`
+
+        This can only be set at bucket **creation** time.
+
+        See https://cloud.google.com/storage/docs/json_api/v1/buckets and
+        https://cloud.google.com/storage/docs/bucket-locations
+
+        .. warning::
+
+            Assignment to 'Bucket.location' is deprecated, as it is only
+            valid before the bucket is created. Instead, pass the location
+            to `Bucket.create`.
+        """
+        warnings.warn(
+            "Assignment to 'Bucket.location' is deprecated, as it is only "
+            "valid before the bucket is created. Instead, pass the location "
+            "to `Bucket.create`.",
+            DeprecationWarning)
+        self._location = value
 
     def get_logging(self):
         """Return info about access logging for this bucket.
@@ -986,8 +1022,8 @@ class Bucket(_PropertyMixin):
         See https://cloud.google.com/storage/docs/json_api/v1/buckets
 
         :rtype: int or ``NoneType``
-        :returns: The metageneration of the bucket or ``None`` if the property
-                  is not set locally.
+        :returns: The metageneration of the bucket or ``None`` if the bucket's
+                  resource has not been loaded from the server.
         """
         metageneration = self._properties.get('metageneration')
         if metageneration is not None:
@@ -1000,8 +1036,8 @@ class Bucket(_PropertyMixin):
         See https://cloud.google.com/storage/docs/json_api/v1/buckets
 
         :rtype: dict or ``NoneType``
-        :returns: Mapping of owner's role/ID. If the property is not set
-                  locally, returns ``None``.
+        :returns: Mapping of owner's role/ID. Returns ``None`` if the bucket's
+                  resource has not been loaded from the server.
         """
         return copy.deepcopy(self._properties.get('owner'))
 
@@ -1012,8 +1048,8 @@ class Bucket(_PropertyMixin):
         See https://cloud.google.com/storage/docs/json_api/v1/buckets
 
         :rtype: int or ``NoneType``
-        :returns: The project number that owns the bucket or ``None`` if the
-                  property is not set locally.
+        :returns: The project number that owns the bucket or ``None`` if
+                  the bucket's resource has not been loaded from the server.
         """
         project_number = self._properties.get('projectNumber')
         if project_number is not None:
@@ -1026,8 +1062,8 @@ class Bucket(_PropertyMixin):
         See https://cloud.google.com/storage/docs/json_api/v1/buckets
 
         :rtype: str or ``NoneType``
-        :returns: The self link for the bucket or ``None`` if the property is
-                  not set locally.
+        :returns: The self link for the bucket or ``None`` if
+                  the bucket's resource has not been loaded from the server.
         """
         return self._properties.get('selfLink')
 
@@ -1069,7 +1105,8 @@ class Bucket(_PropertyMixin):
 
         :rtype: :class:`datetime.datetime` or ``NoneType``
         :returns: Datetime object parsed from RFC3339 valid timestamp, or
-                  ``None`` if the property is not set locally.
+                  ``None`` if the bucket's resource has not been loaded
+                  from the server.
         """
         value = self._properties.get('timeCreated')
         if value is not None:
@@ -1281,11 +1318,7 @@ class Bucket(_PropertyMixin):
         return resp.get('permissions', [])
 
     def make_public(self, recursive=False, future=False, client=None):
-        """Make a bucket public.
-
-        If ``recursive=True`` and the bucket contains more than 256
-        objects / blobs this will cowardly refuse to make the objects public.
-        This is to prevent extremely long runtime of this method.
+        """Update bucket's ACL, granting read access to anonymous users.
 
         :type recursive: bool
         :param recursive: If True, this will make all blobs inside the bucket
@@ -1299,6 +1332,14 @@ class Bucket(_PropertyMixin):
                       ``NoneType``
         :param client: Optional. The client to use.  If not passed, falls back
                        to the ``client`` stored on the current bucket.
+
+        :raises ValueError:
+            If ``recursive`` is True, and the bucket contains more than 256
+            blobs.  This is to prevent extremely long runtime of this
+            method.  For such buckets, iterate over the blobs returned by
+            :meth:`list_blobs` and call
+            :meth:`~google.cloud.storage.blob.Blob.make_public`
+            for each blob.
         """
         self.acl.all().grant_read()
         self.acl.save(client=client)
@@ -1317,10 +1358,11 @@ class Bucket(_PropertyMixin):
                 client=client))
             if len(blobs) > self._MAX_OBJECTS_FOR_ITERATION:
                 message = (
-                    'Refusing to make public recursively with more than '
-                    '%d objects. If you actually want to make every object '
-                    'in this bucket public, please do it on the objects '
-                    'yourself.'
+                    "Refusing to make public recursively with more than "
+                    "%d objects. If you actually want to make every object "
+                    "in this bucket public, iterate through the blobs "
+                    "returned by 'Bucket.list_blobs()' and call "
+                    "'make_public' on each one."
                 ) % (self._MAX_OBJECTS_FOR_ITERATION,)
                 raise ValueError(message)
 
@@ -1329,11 +1371,7 @@ class Bucket(_PropertyMixin):
                 blob.acl.save(client=client)
 
     def make_private(self, recursive=False, future=False, client=None):
-        """Undo the `make_public` method and make the bucket private.
-
-        If ``recursive=True`` and the bucket contains more than 256
-        objects / blobs this will cowardly refuse to make the objects private.
-        This is to prevent extremely long runtime of this method.
+        """Update bucket's ACL, revoking read access for anonymous users.
 
         :type recursive: bool
         :param recursive: If True, this will make all blobs inside the bucket
@@ -1347,6 +1385,14 @@ class Bucket(_PropertyMixin):
                       ``NoneType``
         :param client: Optional. The client to use.  If not passed, falls back
                        to the ``client`` stored on the current bucket.
+
+        :raises ValueError:
+            If ``recursive`` is True, and the bucket contains more than 256
+            blobs.  This is to prevent extremely long runtime of this
+            method.  For such buckets, iterate over the blobs returned by
+            :meth:`list_blobs` and call
+            :meth:`~google.cloud.storage.blob.Blob.make_private`
+            for each blob.
         """
         self.acl.all().revoke_read()
         self.acl.save(client=client)
@@ -1367,8 +1413,9 @@ class Bucket(_PropertyMixin):
                 message = (
                     'Refusing to make private recursively with more than '
                     '%d objects. If you actually want to make every object '
-                    'in this bucket private, please do it on the objects '
-                    'yourself.'
+                    "in this bucket private, iterate through the blobs "
+                    "returned by 'Bucket.list_blobs()' and call "
+                    "'make_private' on each one."
                 ) % (self._MAX_OBJECTS_FOR_ITERATION,)
                 raise ValueError(message)
 
