@@ -14,6 +14,7 @@
 
 import os
 import tempfile
+import re
 import time
 import unittest
 
@@ -23,6 +24,7 @@ import six
 from google.cloud import exceptions
 from google.cloud import storage
 from google.cloud.storage._helpers import _base64_md5hash
+from google.cloud import kms
 
 from test_utils.retry import RetryErrors
 from test_utils.system import unique_resource_id
@@ -39,6 +41,8 @@ def _bad_copy(bad_request):
 
 
 retry_429 = RetryErrors(exceptions.TooManyRequests)
+retry_429_503 = RetryErrors([
+    exceptions.TooManyRequests, exceptions.ServiceUnavailable])
 retry_bad_copy = RetryErrors(exceptions.BadRequest,
                              error_predicate=_bad_copy)
 
@@ -76,10 +80,29 @@ def setUpModule():
 
 
 def tearDownModule():
-    retry = RetryErrors(exceptions.Conflict)
+    retry = RetryErrors(exceptions.Conflict, exceptions.TooManyRequests)
     retry(Config.TEST_BUCKET.delete)(force=True)
 
 
+class TestClient(unittest.TestCase):
+
+    def test_get_service_account_email(self):
+        domain = 'gs-project-accounts.iam.gserviceaccount.com'
+
+        email = Config.CLIENT.get_service_account_email()
+
+        new_style = re.compile(
+            r'service-(?P<projnum>[^@]+)@' + domain)
+        old_style = re.compile(
+            r'{}@{}'.format(Config.CLIENT.project, domain))
+        patterns = [new_style, old_style]
+        matches = [pattern.match(email) for pattern in patterns]
+
+        self.assertTrue(any(
+            match for match in matches if match is not None
+        ))
+
+
 class TestStorageBuckets(unittest.TestCase):
 
     def setUp(self):
@@ -94,7 +117,7 @@ class TestStorageBuckets(unittest.TestCase):
         new_bucket_name = 'a-new-bucket' + unique_resource_id('-')
         self.assertRaises(exceptions.NotFound,
                           Config.CLIENT.get_bucket, new_bucket_name)
-        created = Config.CLIENT.create_bucket(new_bucket_name)
+        created = retry_429(Config.CLIENT.create_bucket)(new_bucket_name)
         self.case_buckets_to_delete.append(new_bucket_name)
         self.assertEqual(created.name, new_bucket_name)
 
@@ -674,6 +697,20 @@ class TestStorageSignURLs(TestStorageFiles):
         self.assertEqual(response.status_code, 200)
         self.assertEqual(response.content, self.LOCAL_FILE)
 
+    def test_create_signed_read_url_w_non_ascii_name(self):
+        blob = self.bucket.blob(u'Caf\xe9.txt')
+        payload = b'Test signed URL for blob w/ non-ASCII name'
+        blob.upload_from_string(payload)
+        self.case_blobs_to_delete.append(blob)
+
+        expiration = int(time.time() + 10)
+        signed_url = blob.generate_signed_url(expiration, method='GET',
+                                              client=Config.CLIENT)
+
+        response = requests.get(signed_url)
+        self.assertEqual(response.status_code, 200)
+        self.assertEqual(response.content, payload)
+
     def test_create_signed_delete_url(self):
         blob = self.bucket.blob('LogoToSign.jpg')
         expiration = int(time.time() + 283473274)
@@ -876,7 +913,7 @@ class TestStorageNotificationCRUD(unittest.TestCase):
         return 'projects/{}/topics/{}'.format(
             Config.CLIENT.project, self.TOPIC_NAME)
 
-    def _intialize_topic(self):
+    def _initialize_topic(self):
         try:
             from google.cloud.pubsub_v1 import PublisherClient
         except ImportError:
@@ -887,14 +924,13 @@ class TestStorageNotificationCRUD(unittest.TestCase):
         binding = policy.bindings.add()
         binding.role = 'roles/pubsub.publisher'
         binding.members.append(
-            'serviceAccount:{}'
-            '@gs-project-accounts.iam.gserviceaccount.com'.format(
-                Config.CLIENT.project))
+            'serviceAccount:{}'.format(
+                Config.CLIENT.get_service_account_email()))
         self.publisher_client.set_iam_policy(self.topic_path, policy)
 
     def setUp(self):
         self.case_buckets_to_delete = []
-        self._intialize_topic()
+        self._initialize_topic()
 
     def tearDown(self):
         retry_429(self.publisher_client.delete_topic)(self.topic_path)
@@ -924,7 +960,7 @@ class TestStorageNotificationCRUD(unittest.TestCase):
         self.case_buckets_to_delete.append(new_bucket_name)
         self.assertEqual(list(bucket.list_notifications()), [])
         notification = bucket.notification(self.TOPIC_NAME)
-        retry_429(notification.create)()
+        retry_429_503(notification.create)()
         try:
             self.assertTrue(notification.exists())
             self.assertIsNotNone(notification.notification_id)
@@ -945,7 +981,7 @@ class TestStorageNotificationCRUD(unittest.TestCase):
             blob_name_prefix=self.BLOB_NAME_PREFIX,
             payload_format=self.payload_format(),
         )
-        retry_429(notification.create)()
+        retry_429_503(notification.create)()
         try:
             self.assertTrue(notification.exists())
             self.assertIsNotNone(notification.notification_id)
@@ -1018,6 +1054,59 @@ class TestKMSIntegration(TestStorageFiles):
             key_name,
         )
 
+    @classmethod
+    def setUpClass(cls):
+        super(TestKMSIntegration, cls).setUpClass()
+
+    def setUp(self):
+        super(TestKMSIntegration, self).setUp()
+        client = kms.KeyManagementServiceClient()
+        project = Config.CLIENT.project
+        location = self.bucket.location.lower()
+        keyring_name = self.KEYRING_NAME
+        purpose = kms.enums.CryptoKey.CryptoKeyPurpose.ENCRYPT_DECRYPT
+
+        # If the keyring doesn't exist create it.
+        keyring_path = client.key_ring_path(project, location, keyring_name)
+
+        try:
+            client.get_key_ring(keyring_path)
+        except exceptions.NotFound:
+            parent = client.location_path(project, location)
+            client.create_key_ring(parent, keyring_name, {})
+
+            # Mark this service account as an owner of the new keyring
+            service_account = Config.CLIENT.get_service_account_email()
+            policy = {
+                "bindings": [
+                    {
+                        "role": "roles/cloudkms.cryptoKeyEncrypterDecrypter",
+                        "members": [
+                            "serviceAccount:" + service_account,
+                        ]
+                    }
+                ]
+            }
+            client.set_iam_policy(keyring_path, policy)
+
+        # Populate the keyring with the keys we use in the tests
+        key_names = [
+            'gcs-test',
+            'gcs-test-alternate',
+            'explicit-kms-key-name',
+            'default-kms-key-name',
+            'override-default-kms-key-name',
+            'alt-default-kms-key-name',
+        ]
+        for key_name in key_names:
+            key_path = client.crypto_key_path(
+                project, location, keyring_name, key_name)
+            try:
+                client.get_crypto_key(key_path)
+            except exceptions.NotFound:
+                key = {'purpose': purpose}
+                client.create_crypto_key(keyring_path, key_name, key)
+
     def test_blob_w_explicit_kms_key_name(self):
         BLOB_NAME = 'explicit-kms-key-name'
         file_data = self.FILES['simple']
@@ -1103,7 +1192,7 @@ class TestKMSIntegration(TestStorageFiles):
         kms_key_name = self._kms_key_name()
 
         # We can't verify it, but ideally we would check that the following
-        # URL was resolvable with our credentals
+        # URL was resolvable with our credentials
         # KEY_URL = 'https://cloudkms.googleapis.com/v1/{}'.format(
         #     kms_key_name)
 
